@@ -1,6 +1,6 @@
 use v5.20;
 use warnings;
-package Log::Fmt 3.004;
+package Log::Fmt 3.006;
 # ABSTRACT: a little parser and emitter of structured log lines
 
 use experimental 'postderef'; # Not dangerous.  Is accepted without changed.
@@ -72,7 +72,7 @@ sub _pairs_to_kvstr_aref {
     }
 
     if (ref $value && ref $value eq 'REF') {
-      $value = $self->string_flogger->flog($$value);
+      $value = $self->string_flogger->flog([ '%s', $$value ]);
     }
 
     if (! defined $value) {
@@ -187,6 +187,25 @@ sub parse_event_string {
   return \@result;
 }
 
+#pod =method parse_event_string_as_hash
+#pod
+#pod     my $hashref = Log::Fmt->parse_event_string_as_hash($line);
+#pod
+#pod This parses the given line as logfmt, then puts the key/value pairs into a hash
+#pod and returns a reference to it.
+#pod
+#pod Because nothing prevents a single key from appearing more than once, you should
+#pod use this with the understanding that data could be lost.  No guarantee is made
+#pod of which value will be preserved.
+#pod
+#pod =cut
+
+sub parse_event_string_as_hash {
+  my ($self, $string) = @_;
+
+  return { $self->parse_event_string($string)->@* };
+}
+
 1;
 
 __END__
@@ -201,7 +220,7 @@ Log::Fmt - a little parser and emitter of structured log lines
 
 =head1 VERSION
 
-version 3.004
+version 3.006
 
 =head1 OVERVIEW
 
@@ -212,13 +231,13 @@ also do that tolerably-okay parsing for you.
 
 =head1 PERL VERSION
 
-This library should run on perls released even a long time ago.  It should work
-on any version of perl released in the last five years.
+This library should run on perls released even a long time ago.  It should
+work on any version of perl released in the last five years.
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
-for any reason, and there is no promise that patches will be accepted to lower
-the minimum required perl.
+for any reason, and there is no promise that patches will be accepted to
+lower the minimum required perl.
 
 =head1 METHODS
 
@@ -251,6 +270,17 @@ said, the string escaping done by the formatter should correctly reverse.
 If the input string is badly formed, hunks that don't appear to be value
 key/value pairs will be presented as values for the key C<junk>.
 
+=head2 parse_event_string_as_hash
+
+    my $hashref = Log::Fmt->parse_event_string_as_hash($line);
+
+This parses the given line as logfmt, then puts the key/value pairs into a hash
+and returns a reference to it.
+
+Because nothing prevents a single key from appearing more than once, you should
+use this with the understanding that data could be lost.  No guarantee is made
+of which value will be preserved.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <cpan@semiotic.systems>
